/* 
Антон (Лилой) Москаленко 
e-mail: liloi@mail.ru 
03/22/06
 
Типы переменных: 
l2vektor var; // двухмерный вектор 
l3vektor var; // трехмерный вектор 
 
Функции: 
ang_mvek(...) - угол между векторами 
scal_vek(...) - скалярное произведение веторов 
otn_x(...) - разделение вектора в отношении по оси x 
otn_y(...) - разделение вектора в отношении по оси y 
otn_x(...) - разделение вектора в отношении по оси z 
is_veks_rav(...) - проверка равенства векторов 
koor_vek(...) - координаты вектора. Поясню на примере: 
 
    вектор из точки a в точку b     
        l3vektor a = koor_vek(a_x, a_y, a_z, b_x, b_y, b_z); 
 
    или, если нам заданы координаты вектора ab мы пишем так: 
        l3vektor a = koor_vek(x,y,z); 
    что аналогично если бы написали так: 
        l3vektor a; 
        a.x = x; 
        a.y = y; 
        a.z = z; 
 
abs_vektor(...) - модуль (длинна) вектора 
 
Данные функции применимы к двух- и трехмерными векторами 
 
cos_3vek_alpha(...), cos_3vek_beta(...), cos_3vek_gamma(...) - напрямные косинусы вектора 
rot_2vek(...) - вращение двухмерного вектора 
 
*/ 
 
#ifndef L_VEKTOR 
#define L_VEKTOR 
#include <math.h> 
 
struct l3vektor 
{ 
    double x; 
    double y; 
    double z; 
}; 
 
struct l2vektor 
{ 
    double x; 
    double y; 
}; 
 
double abs_vektor(l3vektor); 
double abs_vektor(l2vektor); 
double scal_vek(l3vektor, l3vektor); 
double scal_vek(l2vektor, l2vektor); 
l2vektor koor_vek(double, double); 
 
l2vektor rot_2vek(l2vektor a, double ang) 
{ 
    double x = a.x*cos(ang)-a.y*sin(ang); 
    double y = a.y*cos(ang)+a.x*sin(ang); 
    return koor_vek(x,y); 
 
} 
 
double ang_mvek(l3vektor a, l3vektor b) 
{ 
    return acos(scal_vek(a,b)/(abs_vektor(a)*abs_vektor(b))); 
} 
 
double ang_mvek(l2vektor a, l2vektor b) 
{ 
    return acos(scal_vek(a,b)/(abs_vektor(a)*abs_vektor(b))); 
} 
 
double scal_vek(l3vektor a, l3vektor b) 
{ 
 
    return a.x*b.x + a.y*b.y + a.z*b.z; 
} 
 
double scal_vek(l2vektor a, l2vektor b) 
{ 
    return a.x*b.x + a.y*b.y; 
} 
 
double otn_x(double x1, double x2, double otn) 
{ 
    return (x1+otn*x2)/(1+otn); 
} 
 
double otn_y(double y1, double y2, double otn) 
{ 
    return (y1+otn*y2)/(1+otn); 
} 
 
double otn_z(double z1, double z2, double otn) 
{ 
    return (z1+otn*z2)/(1+otn); 
} 
 
bool is_veks_rav(l3vektor a, l3vektor b) 
{ 
    if((a.x==b.x)&&(a.y==b.y)&&(a.z==b.z))return true; else return false; 
} 
 
bool is_veks_rav(l2vektor a, l2vektor b) 
{ 
    if((a.x==b.x)&&(a.y==b.y))return true; else return false; 
} 
 
l3vektor koor_vek(double m_x, double m_y, double m_z, double n_x, double n_y, double n_z) 
{ 
    l3vektor a; 
    a.x = n_x - m_x; 
    a.y = n_y - m_y; 
    a.z = n_z - m_z; 
    return a; 
} 
 
l2vektor koor_vek(double m_x, double m_y, double n_x, double n_y) 
{ 
    l2vektor a; 
    a.x = n_x - m_x; 
    a.y = n_y - m_y; 
    return a; 
} 
 
l3vektor koor_vek(double a_x, double a_y, double a_z) 
{ 
    l3vektor a; 
    a.x = a_x; 
    a.y = a_y; 
    a.z = a_z; 
    return a; 
} 
 
l2vektor koor_vek(double a_x, double a_y) 
{ 
    l2vektor a; 
    a.x = a_x; 
    a.y = a_y; 
    return a; 
} 
 
double abs_vektor(double a_x, double a_y, double a_z) 
{ 
    return pow((pow(a_x,2)+pow(a_y,2)+pow(a_z,2)),(0.5)); 
} 
 
double abs_vektor(l3vektor a) 
{ 
    return pow((pow(a.x,2)+pow(a.y,2)+pow(a.z,2)),(0.5)); 
} 
 
double abs_vektor(double a_x, double a_y) 
{ 
    return pow((pow(a_x,2)+pow(a_y,2)),(0.5)); 
} 
 
double abs_vektor(l2vektor a) 
{ 
    return pow((pow(a.x,2)+pow(a.y,2)),(0.5)); 
} 
 
float cos_vek_alpha(double a_x, double a_y, double a_z) 
{ 
    return a_x/(pow((pow(a_x,2)+pow(a_y,2)+pow(a_z,2)),(0.5))); 
} 
 
float cos_vek_alpha(l3vektor a) 
{ 
    return a.x/(pow((pow(a.x,2)+pow(a.y,2)+pow(a.z,2)),(0.5))); 
} 
 
float cos_vek_beta(double a_x, double a_y, double a_z) 
{ 
    return a_y/(pow((pow(a_x,2)+pow(a_y,2)+pow(a_z,2)),(0.5))); 
} 
 
float cos_vek_beta(l3vektor a) 
{ 
    return a.y/(pow((pow(a.x,2)+pow(a.y,2)+pow(a.z,2)),(0.5))); 
} 
 
float cos_vek_gamma(double a_x, double a_y, double a_z) 
{ 
    return a_z/(pow((pow(a_x,2)+pow(a_y,2)+pow(a_z,2)),(0.5))); 
} 
 
float cos_vek_gamma(l3vektor a) 
{ 
    return a.z/(pow((pow(a.x,2)+pow(a.y,2)+pow(a.z,2)),(0.5))); 
} 
 
#endif 
 
// 
 
 

